View Source SchedEx.TimeScale behaviour (SchedEx v1.1.5)
Constrols time in SchedEx, often used to speed up test runs, or implement custom timing loops.
Default implementation is SchedEx.IdentityTimeScale.
Link to this section Summary
Callbacks
Must return the current time in the specified timezone.
Must returns a float factor to speed up delays by.
Link to this section Callbacks
@callback now(Timex.Types.valid_timezone()) :: DateTime.t()
Must return the current time in the specified timezone.
@callback speedup() :: number()
Must returns a float factor to speed up delays by.